@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use Cwd 'realpath';
 
-our $VERSION   = '1.3094';
+our $VERSION   = '1.3096';
 our $AUTHORITY = 'SUKRIA';
 
 use Dancer::App;
@@ -49,9 +49,11 @@ our @EXPORT    = qw(
   config
   content_type
   dance
+  dancer_version
   debug
   del
   dirname
+  info
   error
   engine
   false
@@ -134,6 +136,7 @@ sub cookies         { Dancer::Cookies->cookies }
 sub config          { Dancer::Config::settings() }
 sub content_type    { Dancer::SharedData->response->content_type(@_) }
 sub dance           { goto &start }
+sub dancer_version  { Dancer->VERSION }
 sub debug           { goto &Dancer::Logger::debug }
 sub del             { Dancer::App->current->registry->universal_add('delete',  @_) }
 sub dirname         { Dancer::FileUtils::dirname(@_) }
@@ -154,6 +157,7 @@ sub halt            { Dancer::SharedData->response->halt(@_);
                       Dancer::Continuation::Halted->new->throw;
                     }
 sub header          { goto &headers }
+sub info            { goto &Dancer::Logger::info }
 sub push_header     { Dancer::SharedData->response->push_header(@_); }
 sub headers         { Dancer::SharedData->response->headers(@_); }
 sub hook            { Dancer::Hook->new(@_) }
@@ -404,7 +408,7 @@ sub _send_file {
             my ( $status, $headers ) = @_;
             my %callbacks = defined $options{'callbacks'} ?
                             %{ $options{'callbacks'} }    :
-                            {};
+                            ();
 
             return sub {
                 my $respond = shift;
@@ -692,6 +696,12 @@ have to change the C<content_type> setting instead.
 
 Alias for the C<start> keyword.
 
+=head2 dancer_version
+
+Returns the version of Dancer. If you need the major version, do something like:
+
+  int(dancer_version);
+
 =head2 debug
 
 Logs a message of debug level:
@@ -1070,6 +1080,14 @@ can be a Dancer::Exception, or a string, or whatever was used to C<die>.
 
 =back
 
+=head2 info
+
+Logs a message of info level:
+
+    info "This is a info message";
+
+See L<Dancer::Logger> for details on how to configure where log messages go.
+
 =head2 layout
 
 This method is deprecated. Use C<set>:
@@ -1137,7 +1155,7 @@ commonly-used methods are summarized below:
 
 I<This method should be called from a route handler>.
 It's an alias for the L<Dancer::Request params accessor|Dancer::Request/"params">. It returns
-an hash reference to all defined parameters. Check C<param> bellow to access quickly to a single
+an hash reference to all defined parameters. Check C<param> below to access quickly to a single
 parameter value.
 
 =head2 param
