@@ -5,6 +5,7 @@ use Carp;
 use Dancer::Route;
 use base 'Dancer::Object';
 use Dancer::Logger;
+use Dancer::Exception qw(:all);
 
 Dancer::Route::Registry->attributes(qw( id ));
 
@@ -91,14 +92,14 @@ sub register_route {
 sub any_add {
     my ($self, $pattern, @rest) = @_;
 
-    my @methods = qw(get post put delete options);
+    my @methods = qw(get post put patch delete options);
 
     if (ref($pattern) eq 'ARRAY') {
         @methods = @$pattern;
         $pattern = shift @rest;
     }
 
-    croak "Syntax error, methods should be provided as an ARRAY ref"
+    raise core_route => "Syntax error, methods should be provided as an ARRAY ref"
       if grep {$_ eq $pattern} @methods;
 
     $self->universal_add($_, $pattern, @rest) for @methods;
